@@ -26,10 +26,6 @@
 #include <config.h>
 #include "gst.h"
 
-#ifdef HAVE_POLKIT
-#include "gst-polkit-action.h"
-#endif
-
 #include "passwd.h"
 #include "callbacks.h"
 #include "table.h"
@@ -41,30 +37,44 @@
 
 extern GstTool *tool;
 
-/* Unlock signal */
-
+/* PolkitLockButton state has changed, reflect this in the UI */
 void
-on_unlocked (GstDialog *dialog)
+on_lock_changed (GstDialog *dialog)
 {
 	GtkWidget *users_table;
 	GtkTreeModel *model, *store;
+	GtkTreeSelection *selection;
 	GtkTreeIter iter;
+	OobsUser *self, *user;
 	gboolean valid;
+	gboolean is_authenticated;
 
 	users_table = gst_dialog_get_widget (dialog, "users_table");
 
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (users_table));
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (users_table));
 	store = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
 
+	is_authenticated = gst_dialog_is_authenticated (tool->main_dialog);
+	self = oobs_self_config_get_user (OOBS_SELF_CONFIG (GST_USERS_TOOL (tool)->self_config));
+
 	valid = gtk_tree_model_get_iter_first (store, &iter);
 
 	while (valid) {
-		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
-				    COL_USER_SENSITIVE, TRUE,
+		gtk_tree_model_get (store, &iter,
+				    COL_USER_OBJECT, &user,
 				    -1);
 
+		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
+				    COL_USER_SENSITIVE, is_authenticated | (user == self),
+				    -1);
+
+		g_object_unref (user);
 		valid = gtk_tree_model_iter_next (store, &iter);
 	}
+
+	/* Update the status depending on the selected user */
+	on_table_selection_changed (selection, NULL);
 }
 
 /* Common stuff to users and groups tables */
@@ -72,6 +82,9 @@ on_unlocked (GstDialog *dialog)
 static void
 actions_set_sensitive (gint table, gint count, OobsUser *user)
 {
+	OobsObject *object = GST_USERS_TOOL (tool)->self_config;
+	gboolean sensitive;
+
 	switch (table) {
 	case TABLE_USERS:
 		gst_dialog_try_set_sensitive (tool->main_dialog,
@@ -81,9 +94,10 @@ actions_set_sensitive (gint table, gint count, OobsUser *user)
 					      gst_dialog_get_widget (tool->main_dialog, "user_delete"),
 					      (count > 0));
 
-		
+		sensitive = count == 1 && gst_dialog_is_authenticated (tool->main_dialog)
+				       || (user == oobs_self_config_get_user (OOBS_SELF_CONFIG (object)));
 		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "user_settings"),
-					  (count == 1 && (gst_dialog_is_authenticated (tool->main_dialog) || oobs_user_get_active (user))));
+					  sensitive);
 		break;
 	case TABLE_GROUPS:
 		gst_dialog_try_set_sensitive (tool->main_dialog,
@@ -103,7 +117,7 @@ actions_set_sensitive (gint table, gint count, OobsUser *user)
 }
 
 void
-on_table_clicked (GtkTreeSelection *selection, gpointer data)
+on_table_selection_changed (GtkTreeSelection *selection, gpointer data)
 {
 	gint count, table;
 	gboolean active;
@@ -172,6 +186,9 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer da
 	selection = gtk_tree_view_get_selection (treeview);
 	cont = gtk_tree_selection_count_selected_rows (selection);
 
+	if (event->window != gtk_tree_view_get_bin_window (treeview))
+		return FALSE;
+
 	if (event->button == 3)	{
 		gtk_widget_grab_focus (GTK_WIDGET (treeview));
 		
@@ -196,6 +213,7 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer da
 			GtkTreePath *path;
 			GtkTreeIter iter;
 			OobsUser *user;
+			OobsObject *object;
 
 			selected = gtk_tree_selection_get_selected_rows (selection, &model);
 			path = (GtkTreePath *) selected->data;
@@ -203,7 +221,8 @@ on_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer da
 			gtk_tree_model_get_iter (model, &iter, path);
 			gtk_tree_model_get (model, &iter, COL_USER_OBJECT, &user, -1);
 
-			if (!oobs_user_get_active (user))
+			object = GST_USERS_TOOL (tool)->self_config;
+			if (user != oobs_self_config_get_user (OOBS_SELF_CONFIG (object)))
 				return FALSE;
 		}
 
@@ -281,8 +300,8 @@ on_user_new_clicked (GtkButton *button, gpointer user_data)
 		oobs_list_set (users_list, &list_iter, user);
 
 		users_table_add_user (user, &list_iter);
-		oobs_object_commit (GST_USERS_TOOL (tool)->users_config);
-		oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+		gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config);
+		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
 	}
 }
 
@@ -324,22 +343,19 @@ on_user_settings_clicked (GtkButton *button, gpointer user_data)
 
 		if (gst_dialog_is_authenticated (tool->main_dialog)) {
 			/* change users/groups configuration */
-			oobs_object_commit (GST_USERS_TOOL (tool)->users_config);
-			oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+			gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config);
+			gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
+#ifdef HAVE_POLKIT
+		/* With PolicyKit1, we don't have to check for authorizations: just try to commit,
+		 * the backend will trigger authentication if possible, or fail */
 		} else {
 			OobsObject *object = GST_USERS_TOOL (tool)->self_config;
 
 			/* change self, only if it is the modified user */
 			if (user == oobs_self_config_get_user (OOBS_SELF_CONFIG (object))) {
-#ifdef HAVE_POLKIT
-				GstPolKitAction *action;
-				action = gst_polkit_action_new (oobs_object_get_authentication_action (object),
-								GTK_WIDGET (tool->main_dialog));
-
-				if (gst_polkit_action_authenticate (action))
-					oobs_object_commit (GST_USERS_TOOL (tool)->self_config);
-#endif
+				gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
 			}
+#endif
 		}
 	}
 
@@ -367,7 +383,7 @@ on_user_delete_clicked (GtkButton *button, gpointer user_data)
 	g_list_foreach (list, (GFunc) gtk_tree_row_reference_free, NULL);
 	g_list_free (list);
 
-	oobs_object_commit (GST_USERS_TOOL (tool)->users_config);
+	gst_tool_commit (tool, GST_USERS_TOOL (tool)->users_config);
 }
 
 void
@@ -402,7 +418,7 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 	response = group_settings_dialog_run (dialog, group);
 
 	if (response == GTK_RESPONSE_OK) {
-		group_settings_dialog_get_data (group);
+		group = group_settings_dialog_get_group ();
 
 		config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
 		groups_list = oobs_groups_config_get_groups (config);
@@ -410,7 +426,7 @@ on_group_new_clicked (GtkButton *button, gpointer user_data)
 		oobs_list_set (groups_list, &list_iter, group);
 
 		groups_table_add_group (group, &list_iter);
-		oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
 	}
 }
 
@@ -450,7 +466,7 @@ on_group_settings_clicked (GtkButton *button, gpointer user_data)
 								  &filter_iter, &iter);
 		group_settings_dialog_get_data (group);
 		groups_table_set_group (group, list_iter, &filter_iter);
-		oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
 	}
 
 	g_object_unref (group);
@@ -478,7 +494,7 @@ on_group_delete_clicked (GtkButton *button, gpointer user_data)
 	g_list_foreach (list, (GFunc) gtk_tree_row_reference_free, NULL);
 	g_list_free (list);
 
-	oobs_object_commit (GST_USERS_TOOL (tool)->groups_config);
+	gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
 }
 
 /* User settings callbacks */
