@@ -60,7 +60,7 @@ static GstDialogSignal signals[] = {
 	{ "groups_dialog_help",                 "clicked",              G_CALLBACK (on_groups_dialog_show_help) },
 	{ NULL }};
 
-static const gchar *policy_widgets [] = {
+const gchar *policy_widgets [] = {
 	"user_new",
 	"user_delete",
 	"groups_table",
@@ -72,6 +72,7 @@ static const gchar *policy_widgets [] = {
 	"profile_settings",
 	"user_settings_name",
 	"user_settings_profile_menu",
+	"user_passwd_no_check",
 	"user_privileges",
 	"user_settings_home",
 	"user_settings_shell",
