@@ -146,15 +146,6 @@ user_delete (GtkTreeModel *model, GtkTreePath *path)
 	return retval;
 }
 
-static void
-setup_groups_combo (GtkWidget *widget)
-{
-	GtkWidget *table = gst_dialog_get_widget (tool->main_dialog, "groups_table");
-	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-
-	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), model);
-}
-
 static void
 set_entry_text (GtkWidget *entry, const gchar *text)
 {
@@ -231,7 +222,7 @@ get_main_group (const gchar *name)
 		oobs_list_set (groups_list, &list_iter, group);
 
 		groups_table_add_group (group, &list_iter);
-		oobs_object_commit (OOBS_OBJECT (config));
+		gst_tool_commit (tool, OOBS_OBJECT (config));
 
 		return group;
 	}
@@ -466,7 +457,7 @@ user_settings_dialog_new (OobsUser *user)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
 	}
 	else {
-		gtk_widget_set_sensitive (widget, TRUE);
+		gst_dialog_try_set_sensitive (tool->main_dialog, widget, TRUE);
 		if (is_user_in_group (user, no_passwd_login_group))
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 		else
